#!/bin/sh

echo "+++++ Checking current user rights..."

if [ "$(id -u root)" = "$(id -u)" ] ; then
    :
else
    echo "ERROR: The current user id is not root (`id|awk '{print $1}'`)."
    exit 1
fi
echo


if [ "X$PVSW_ROOT" = "X" ] ; then
    PVSW_ROOT=/usr/local/psql
fi
PATH=$PVSW_ROOT/bin:$PATH
if [ $(uname -s) = "Darwin" ]
then
    DYLD_LIBRARY_PATH=$PVSW_ROOT/bin:$PVSW_ROOT/lib:$PVSW_ROOT/lib64:$DYLD_LIBRARY_PATH
    export DYLD_LIBRARY_PATH
    SO_EXTENSION="dylib"
else
    LD_LIBRARY_PATH=$PVSW_ROOT/bin:$PVSW_ROOT/lib:$PVSW_ROOT/lib64:$LD_LIBRARY_PATH
    SO_EXTENSION="so"
fi


echo "+++++ Removing PSQL files..."

HOMEDIR=`grep "^psql:" /etc/passwd | cut -d: -f6`
rm -f  $HOMEDIR/.cshrc
rm -f  $HOMEDIR/.bash_profile
rm -f  $HOMEDIR/.bash_history
rm -f  $HOMEDIR/.bashrc

rm -f  $PVSW_ROOT/pvinst.log
rm -f  $PVSW_ROOT/LICENSE
rm -f  $PVSW_ROOT/PSQL_SE_Third_Party_Notice
rm -f  $PVSW_ROOT/PSQL_Client_Third_Party_Notice
rm -Rf $PVSW_ROOT/bin
rm -Rf $PVSW_ROOT/data/DEMODATA
rm -Rf $PVSW_ROOT/data/TEMPDB
rm -f  $PVSW_ROOT/data/samples/sample.btr
rm -f  $PVSW_ROOT/data/samples/upper.alt
rmdir $PVSW_ROOT/data 2>/dev/null
rmdir $PVSW_ROOT/data/samples 2>/dev/null
rm -Rf $PVSW_ROOT/docs
rm -f  $PVSW_ROOT/etc/confmig.log
rm -f  $PVSW_ROOT/etc/sqlmgr.pid
rm -Rf $PVSW_ROOT/lib
rm -Rf $PVSW_ROOT/lib64
rm -Rf $PVSW_ROOT/jre
rm -Rf $PVSW_ROOT/log
rm -Rf $PVSW_ROOT/man
rm -Rf $PVSW_ROOT/schemas
echo

if insserv -n > /dev/null 2>&1
then
# In situations where insserv is available, 'preun' is the last point at which
# "insserv -r psql" can be invoked because the main uninstall removes /etc/init.d/psql
# we do that by calling it from preuninstall.sh
    echo ""
else
# So here we just handle cleanup for chkconfig style rc links if they are present.
    echo "+++++ Removing PSQL daemon scripts..."
    if [ -d /etc/rc.d/rc0.d ]; then
        RCDIR=/etc/rc.d
    fi
    if [ -d /etc/rc0.d ]; then
        RCDIR=/etc
    fi
    KILLS=K92psql
    STARTS=S92psql
    rm -f $RCDIR/rc0.d/$KILLS
    rm -f $RCDIR/rc1.d/$KILLS
    rm -f $RCDIR/rc2.d/$STARTS
    rm -f $RCDIR/rc3.d/$STARTS
    rm -f $RCDIR/rc4.d/$STARTS
    rm -f $RCDIR/rc5.d/$STARTS
    rm -f $RCDIR/rc6.d/$KILLS
fi

rm -f /etc/init.d/psql /usr/lib/ocf/resource.d/heartbeat/psql

# remove lock file directory (Debian Linux uses a different lock file directory then the other flavors of Linux)
if [ -d /var/lock/subsys ] ; then
    rm -f /var/lock/subsys/psql
else
    if [ $(uname -s) = "Darwin" ]
    then
        rm -f /var/tmp/psql
    else
        rm -f /var/state/psql
    fi
fi
SERVICES=/etc/services
if [ -f $SERVICES ] ; then
    sed '/Pervasive PSQL MKDE daemon/d' $SERVICES > /tmp/services
    mv -f /tmp/services $SERVICES
fi
echo


echo "+++++ Removing PSQL PAM settings..."

PAMCONF=/etc/pam.conf
PAMDIR=/etc/pam.d
if [ -f $PAMCONF ] ; then
    FOUND=`grep -c "^pvsw" $PAMCONF`
    if [ $? -eq 0 ] ; then
	sed '/^pvsw/d' $PAMCONF > /tmp/pam.conf
	mv -f /tmp/pam.conf $PAMCONF
    fi
fi
rm -f $PAMDIR/pvsw
rm -f $PAMDIR/pvswauth
rm -f /lib/security/pvswauth
rm -f /lib/security/pam_pvsw.${SO_EXTENSION}*
rm -f /lib64/security/pvswauth
rm -f /lib64/security/pam_pvsw.${SO_EXTENSION}*
echo


echo "Uninstall has successfully completed."
echo



















